pub struct HealthResponse { /* private fields */ }Trait Implementations
Sourceimpl JsonSchema for HealthResponse
impl JsonSchema for HealthResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HealthResponse
impl RefUnwindSafe for HealthResponse
impl Send for HealthResponse
impl Sync for HealthResponse
impl Unpin for HealthResponse
impl UnsafeUnpin for HealthResponse
impl UnwindSafe for HealthResponse