pub struct LinkArgs {Show 13 fields
pub from: Option<String>,
pub from_id: Option<i64>,
pub to: Option<String>,
pub to_id: Option<i64>,
pub relation: String,
pub weight: Option<f64>,
pub namespace: Option<String>,
pub format: OutputFormat,
pub json: bool,
pub db: Option<String>,
pub create_missing: bool,
pub entity_type: EntityType,
pub strict_relations: bool,
}Fields
from: Option<String>Source ENTITY name (graph node, not memory). Entities are curated via
remember --graph-stdin, created by enrich, or auto-created via --create-missing.
Use graph entities to list available entity names. Also accepts the alias --name.
Conflicts with --from-id.
from_id: Option<i64>Source entity ID (unambiguous alternative to --from). Conflicts with --from.
to: Option<String>Target ENTITY name (graph node, not memory). See --from for sourcing entity names.
Conflicts with --to-id.
to_id: Option<i64>Target entity ID (unambiguous alternative to --to). Conflicts with --to.
relation: StringRelation type between entities. Canonical values: applies-to, uses, depends-on, causes, fixes, contradicts, supports, follows, related, mentions, replaces, tracked-in. Any kebab-case or snake_case string is also accepted as a custom relation.
weight: Option<f64>namespace: Option<String>format: OutputFormatjson: booldb: Option<String>create_missing: boolAuto-create entities when they do not exist. Created entities default to
type concept unless --entity-type specifies a different type.
entity_type: EntityTypeEntity type assigned to auto-created entities (only effective with --create-missing).
strict_relations: boolReject non-canonical relation types with exit 1.
When set, any relation not in the canonical list causes an immediate error. Canonical values: applies-to, uses, depends-on, causes, fixes, contradicts, supports, follows, related, mentions, replaces, tracked-in.