Module rename_entity

Module rename_entity 

Handler for the rename-entity CLI subcommand.

Renames an entity preserving all relationships and memory bindings. Only the name column in entities and the corresponding vec_entities row need updating because relationships use integer FK entity_id.

Structs

RenameEntityArgs

Functions

run