pub fn run(args: SplitBodyArgs) -> Result<(), AppError>Expand description
Validates the parsed args and dispatches to single or batch mode.
pub fn run(args: SplitBodyArgs) -> Result<(), AppError>Validates the parsed args and dispatches to single or batch mode.