set_active_embedding_dim

Function set_active_embedding_dim 

pub fn set_active_embedding_dim(dim: usize)
Records the dimensionality found in the opened database (schema_meta.dim). Out-of-range values are ignored. The env var, when set, always wins over this value (see embedding_dim).