pub fn default_backend() -> SharedBackendExpand description
Factory that builds the default backend for the current build configuration.
pub fn default_backend() -> SharedBackendFactory that builds the default backend for the current build configuration.