Module errors_msg

Module errors_msg 

Error messages for AppError variants — always English.

These strings end up inside AppError inner fields and may appear in deterministic JSON stdout (e.g. ingest NDJSON). Portuguese translations for stderr live in pub mod app_error_pt and are applied by localized_message_for(Language::Portuguese).

Functions

concurrent_process_conflict
Localized message for concurrent_process_conflict.
database_not_found
Localized message for database_not_found.
duplicate_memory
Localized message for duplicate_memory.
duplicate_memory_soft_deleted
Localized message for duplicate_memory_soft_deleted.
entity_limit_exceeded
Localized message for entity_limit_exceeded.
entity_not_found
Localized message for entity_not_found.
memory_not_found
Localized message for memory_not_found.
memory_or_entity_not_found
Localized message for memory_or_entity_not_found.
no_recall_results
Localized message for no_recall_results.
optimistic_lock_conflict
Localized message for optimistic_lock_conflict.
relationship_limit_exceeded
Localized message for relationship_limit_exceeded.
relationship_not_found
Localized message for relationship_not_found.
soft_deleted_memory_not_found
Localized message for soft_deleted_memory_not_found.
version_not_found
Localized message for version_not_found.