key_is_envelope_only

Function key_is_envelope_only 

pub fn key_is_envelope_only(flag: &str, key: &str, array: &str) -> String
GAP-SG-203: the key names a member of the envelope, not a field of the elements the predicate would be applied to.