Executor compatibility matrix (v1.0.75 — G22)
Static map of which versions support which flags, used by the adapters.
Executor compatibility matrix (v1.0.75 — G22)
Static map of which versions support which flags, used by the adapters.