pub fn increment_degree(
conn: &Connection,
entity_id: i64,
) -> Result<(), AppError>Expand description
Increments the degree counter of an entity by one.
Errors
Returns AppError::Database when the underlying SQLite operation fails.
pub fn increment_degree(
conn: &Connection,
entity_id: i64,
) -> Result<(), AppError>Increments the degree counter of an entity by one.
Returns AppError::Database when the underlying SQLite operation fails.