apply

Function apply 

pub fn apply(surface: &AgentSurface, value: Value) -> Result<Value, AppError>
Applies surface to value, honouring the invariants documented above.

Errors

Returns AppError::Usage when the request cannot be honoured as asked โ€” see gate for the three shapes that earns.