pub fn apply(surface: &AgentSurface, value: Value) -> ValueExpand description
Applies surface to value, honouring the invariants documented above.
pub fn apply(surface: &AgentSurface, value: Value) -> ValueApplies surface to value, honouring the invariants documented above.