pub struct ReclassifyRelationArgs {
pub source: Option<String>,
pub target: Option<String>,
pub from_relation: String,
pub to_relation: String,
pub batch: bool,
pub filter_source_type: Option<EntityType>,
pub filter_target_type: Option<EntityType>,
pub dry_run: bool,
pub namespace: Option<String>,
pub format: OutputFormat,
pub json: bool,
pub db: Option<String>,
}Fields
source: Option<String>Source entity name (single mode). Mutually exclusive with –batch.
target: Option<String>Target entity name (single mode). Mutually exclusive with –batch.
from_relation: StringCurrent relation type to rename. Required in both single and batch modes.
to_relation: StringNew relation type to assign. Required in both single and batch modes.
batch: boolEnable batch reclassification of all edges with –from-relation. Requires –from-relation and –to-relation.
filter_source_type: Option<EntityType>Filter batch: only rename edges whose source entity has this type.
filter_target_type: Option<EntityType>Filter batch: only rename edges whose target entity has this type.
dry_run: boolPreview count without committing changes.
namespace: Option<String>format: OutputFormatjson: booldb: Option<String>Trait Implementations
Sourceimpl Args for ReclassifyRelationArgs
impl Args for ReclassifyRelationArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for ReclassifyRelationArgs
impl FromArgMatches for ReclassifyRelationArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for ReclassifyRelationArgs
impl RefUnwindSafe for ReclassifyRelationArgs
impl Send for ReclassifyRelationArgs
impl Sync for ReclassifyRelationArgs
impl Unpin for ReclassifyRelationArgs
impl UnsafeUnpin for ReclassifyRelationArgs
impl UnwindSafe for ReclassifyRelationArgs