Module graph

Module graph 

Graph traversal helpers over the entities and relationships tables. Entity graph traversal (BFS over memory_entities + relations).

Queries the SQLite entity and relation tables to expand neighbourhood sets used by the related and recall commands.

Functions

traverse_from_memories
Traverses the entity graph by BFS from seed memories.
traverse_from_memories_with_hops
BFS graph traversal that also returns the hop distance for each reached memory.