Graph traversal helpers over the entities and relationships tables. Entity graph traversal (BFS over memory_entities + relations).
Queries the SQLite entity and relation tables to expand neighbourhood
sets used by the related and recall commands.
Functions
- traverse_
from_ memories - Traverses the entity graph by BFS from seed memories.
- traverse_
from_ memories_ with_ hops - BFS graph traversal that also returns the hop distance for each reached memory.